@@ -1,10 +1,7 @@
 use strict;
 use warnings;
 package Device::RFXCOM::Decoder::Oregon;
-BEGIN {
-  $Device::RFXCOM::Decoder::Oregon::VERSION = '1.110800';
-}
-
+$Device::RFXCOM::Decoder::Oregon::VERSION = '1.142010';
 # ABSTRACT: Device::RFXCOM::Decoder::Oregon decode Oregon RF messages
 
 
@@ -117,6 +114,11 @@ my %types =
     method => 'pcr800_rain',
    },
 
+   type_length_key(0xca48, 68) =>
+   {
+    part => 'THWR800', checksum => \&checksum1, method => 'common_temp',
+   },
+
    # for testing
    type_length_key(0xfefe, 80) => { part => 'TEST' },
   );
@@ -548,17 +550,19 @@ sub type_length_key {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Device::RFXCOM::Decoder::Oregon - Device::RFXCOM::Decoder::Oregon decode Oregon RF messages
 
 =head1 VERSION
 
-version 1.110800
+version 1.142010
 
 =head1 SYNOPSIS
 
@@ -749,14 +753,13 @@ RFXCOM website: http://www.rfxcom.com/
 
 =head1 AUTHOR
 
-Mark Hindess <soft-rfxcom@temporalanomaly.com>
+Mark Hindess <soft-cpan@temporalanomaly.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Mark Hindess.
+This software is copyright (c) 2014 by Mark Hindess.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
