@@ -1,10 +1,7 @@
 use strict;
 use warnings;
 package Device::RFXCOM::Encoder::X10;
-BEGIN {
-  $Device::RFXCOM::Encoder::X10::VERSION = '1.110800';
-}
-
+$Device::RFXCOM::Encoder::X10::VERSION = '1.142010';
 # ABSTRACT: Device::RFXCOM::Encoder::X10 encode X10 RF messages
 
 
@@ -84,17 +81,19 @@ sub _encode_x10 {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Device::RFXCOM::Encoder::X10 - Device::RFXCOM::Encoder::X10 encode X10 RF messages
 
 =head1 VERSION
 
-version 1.110800
+version 1.142010
 
 =head1 SYNOPSIS
 
@@ -102,9 +101,8 @@ version 1.110800
 
 =head1 DESCRIPTION
 
-This is a module for encoding RF messages for X10
-(L<http://www.x10.eu/>) devices so that that can be dispatched to
-an RFXCOM RF transmitter.
+This is a module for encoding RF messages for X10 devices so that they
+can be dispatched to an RFXCOM RF transmitter.
 
 =head1 METHODS
 
@@ -126,14 +124,13 @@ RFXCOM website: http://www.rfxcom.com/
 
 =head1 AUTHOR
 
-Mark Hindess <soft-rfxcom@temporalanomaly.com>
+Mark Hindess <soft-cpan@temporalanomaly.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Mark Hindess.
+This software is copyright (c) 2014 by Mark Hindess.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
