@@ -1,10 +1,7 @@
 use strict;
 use warnings;
 package Device::RFXCOM::Response::Security;
-BEGIN {
-  $Device::RFXCOM::Response::Security::VERSION = '1.110800';
-}
-
+$Device::RFXCOM::Response::Security::VERSION = '1.142010';
 # ABSTRACT: Device::RFXCOM::Response class for Security messages from RFXCOM receiver
 
 
@@ -43,17 +40,19 @@ sub summary {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Device::RFXCOM::Response::Security - Device::RFXCOM::Response class for Security messages from RFXCOM receiver
 
 =head1 VERSION
 
-version 1.110800
+version 1.142010
 
 =head1 SYNOPSIS
 
@@ -110,14 +109,13 @@ RFXCOM website: http://www.rfxcom.com/
 
 =head1 AUTHOR
 
-Mark Hindess <soft-rfxcom@temporalanomaly.com>
+Mark Hindess <soft-cpan@temporalanomaly.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Mark Hindess.
+This software is copyright (c) 2014 by Mark Hindess.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
